@@ -30,7 +30,7 @@ def weights_shift(weight_mat=None, trading_delay = 1):
     weight_mat = weight_mat.shift(trading_delay)
     return weight_mat, last_predicted_weights
 
-def process_weights(w=None, df=None, s=None, n=None, low_bound=None, up_bound=None, weight_cutting_rate = 0.7, normalize = True , display=False, max_iteration = 50, trading_delay=1 , force_min_bound = False):
+def process_weights(w=None, df=None, s=None, n=None, low_bound=None, up_bound=None, weight_cutting_rate = 0.7, normalize = True , display=False, max_iteration = 50, trading_delay=1):
     """ Process weight to respect constraints.
     Parameters
     ----------
@@ -69,10 +69,7 @@ def process_weights(w=None, df=None, s=None, n=None, low_bound=None, up_bound=No
             continue
         # we override the bound constraint when the universe cardinality is too low
         local_up_bound = max(1./assets.sum(),up_bound)
-        if force_min_bound:
-            local_low_bound = min(1. / assets.sum(), low_bound)
-        else :
-            local_low_bound=low_bound
+        local_low_bound = min(1. / assets.sum(), low_bound)
 
         weight_vect[assets, 0] = w[test_slice.start][assets]
 
